@@ -340,7 +340,7 @@ class Users(_defaults_.Defaults):
 			except Exception as e:  return dev0s.response.error(f"Failed to retrieve django user {identifier}, error: {e}.")
 
 		# invalid.
-		else: return dev0s.response.error(f"Define one of the following parameters: [username, email].")
+		else: return dev0s.response.error(f"{self.__traceback__(function='get')}: Define one of the following parameters: [username, email].")
 
 		# success.
 		return dev0s.response.success(f"Successfully retrieved django user {identifier}.", {
@@ -371,12 +371,12 @@ class Users(_defaults_.Defaults):
 				exists = DjangoUser.objects.filter(username=username).exists()
 
 				# success.
-				return dev0s.response.success(f"Successfully checked the existsance of django user {username}.", {
+				return dev0s.response.success(f"Successfully checked the existance of django user {username}.", {
 					"exists":exists,
 				})
 
 			# error.
-			except Exception as e:  return dev0s.response.error(f"Failed to check the existsance of django user {username}, error: {e}.")
+			except Exception as e:  return dev0s.response.error(f"Failed to check the existance of django user {username}, error: {e}.")
 
 		# by email.
 		elif email != None:
@@ -387,12 +387,12 @@ class Users(_defaults_.Defaults):
 			response = self.get(email=email)
 			if response.error != None and "User matching query does not exist" not in response.error: return response
 			elif response.error != None and "User matching query does not exist" in response.error: exists = False
-			return dev0s.response.success(f"Successfully checked the existsance of django user {identifier}.", {
+			return dev0s.response.success(f"Successfully checked the existance of django user {identifier}.", {
 				"exists":exists,
 			})
 
 		# invalid.
-		else: return dev0s.response.error(f"Define one of the following parameters: [username, email].")
+		else: return dev0s.response.error(f"{self.__traceback__(function='exists')}: Define one of the following parameters: [username, email].")
 
 
 		#
